==> WWW-GoKGS-0.01.tar.gz: WWW-GoKGS-0.01/t/data/TournEntrants/id-845-sort-s/expected.pl <==
{
  'entrants' => [
    {
      'name' => 'MantisArms',
      'notes' => undef,
      'position' => undef,
      'rank' => '7d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Winner'
    },
    {
      'name' => 'goutte',
      'notes' => undef,
      'position' => undef,
      'rank' => '5d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 4'
    },
    {
      'name' => 'ichigo5',
      'notes' => undef,
      'position' => undef,
      'rank' => '3d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 3'
    },
    {
      'name' => 'dogbert',
      'notes' => undef,
      'position' => undef,
      'rank' => '4d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 2'
    },
    {
      'name' => 'martin97',
      'notes' => undef,
      'position' => undef,
      'rank' => '2d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 2'
    },
    {
      'name' => 'Soifard',
      'notes' => undef,
      'position' => undef,
      'rank' => '4d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 2'
    },
    {
      'name' => 'backpack1',
      'notes' => undef,
      'position' => undef,
      'rank' => '3d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'ben0',
      'notes' => undef,
      'position' => undef,
      'rank' => '6d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'Chimpsky',
      'notes' => undef,
      'position' => undef,
      'rank' => '1d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'edenchen',
      'notes' => undef,
      'position' => undef,
      'rank' => '1d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'Goprince',
      'notes' => undef,
      'position' => undef,
      'rank' => '5d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'xhu98',
      'notes' => undef,
      'position' => undef,
      'rank' => '4d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'Zoro',
      'notes' => undef,
      'position' => undef,
      'rank' => '1d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'koreanface',
      'notes' => undef,
      'position' => undef,
      'rank' => '4d',
      'score' => undef,
      'sodos' => undef,
      'sos' => undef,
      'standing' => 'Quit before round 3'
    }
  ],
  'links' => {
    'entrants' => [
      {
        'sort_by' => 'name',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=n&id=845')}, 'URI::http' )
      },
      {
        'sort_by' => 'result',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=s&id=845')}, 'URI::http' )
      }
    ],
    'rounds' => [
      {
        'end_time' => '2013-10-12T19:05Z',
        'round' => '1',
        'start_time' => '2013-10-12T17:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=1')}, 'URI::http' )
      },
      {
        'end_time' => '2013-10-12T21:05Z',
        'round' => '2',
        'start_time' => '2013-10-12T19:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=2')}, 'URI::http' )
      },
      {
        'end_time' => '2013-10-12T23:05Z',
        'round' => '3',
        'start_time' => '2013-10-12T21:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=3')}, 'URI::http' )
      },
      {
        'end_time' => '2013-10-13T19:05Z',
        'round' => '4',
        'start_time' => '2013-10-13T17:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=4')}, 'URI::http' )
      }
    ]
  },
  'name' => 'KGS Meijin Qualifier October 2013',
  'results' => {}
}

==> WWW-GoKGS-0.02.tar.gz: WWW-GoKGS-0.02/t/data/TournEntrants/id-845-sort-s/expected.pl <==
{
  'entrants' => [
    {
      'name' => 'MantisArms',
      'rank' => '7d',
      'standing' => 'Winner'
    },
    {
      'name' => 'goutte',
      'rank' => '5d',
      'standing' => 'Knocked out in round 4'
    },
    {
      'name' => 'ichigo5',
      'rank' => '3d',
      'standing' => 'Knocked out in round 3'
    },
    {
      'name' => 'dogbert',
      'rank' => '4d',
      'standing' => 'Knocked out in round 2'
    },
    {
      'name' => 'martin97',
      'rank' => '2d',
      'standing' => 'Knocked out in round 2'
    },
    {
      'name' => 'Soifard',
      'rank' => '4d',
      'standing' => 'Knocked out in round 2'
    },
    {
      'name' => 'backpack1',
      'rank' => '3d',
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'ben0',
      'rank' => '6d',
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'Chimpsky',
      'rank' => '1d',
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'edenchen',
      'rank' => '1d',
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'Goprince',
      'rank' => '5d',
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'xhu98',
      'rank' => '4d',
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'Zoro',
      'rank' => '1d',
      'standing' => 'Knocked out in round 1'
    },
    {
      'name' => 'koreanface',
      'rank' => '4d',
      'standing' => 'Quit before round 3'
    }
  ],
  'links' => {
    'entrants' => [
      {
        'sort_by' => 'name',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=n&id=845')}, 'URI::http' )
      },
      {
        'sort_by' => 'result',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=s&id=845')}, 'URI::http' )
      }
    ],
    'rounds' => [
      {
        'end_time' => '2013-10-12T19:05Z',
        'round' => 1,
        'start_time' => '2013-10-12T17:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=1')}, 'URI::http' )
      },
      {
        'end_time' => '2013-10-12T21:05Z',
        'round' => 2,
        'start_time' => '2013-10-12T19:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=2')}, 'URI::http' )
      },
      {
        'end_time' => '2013-10-12T23:05Z',
        'round' => 3,
        'start_time' => '2013-10-12T21:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=3')}, 'URI::http' )
      },
      {
        'end_time' => '2013-10-13T19:05Z',
        'round' => 4,
        'start_time' => '2013-10-13T17:05Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=845&round=4')}, 'URI::http' )
      }
    ]
  },
  'name' => 'KGS Meijin Qualifier October 2013'
}
